/*
 * Authors:		Sunil Mathew
 *                      Micah Colon
 *
 * Date last modified:  4/30/04
 */

/* Message types used by PowerMaster and PowerSlave. */

#ifndef __PowerMsg_H__
#define __PowerMsg_H__


// Important values

#define MAX_NODES 15
#define DEFAULT_CLOCK_INTERVAL TOS_I1024PS // When combined, this interval
#define DEFAULT_CLOCK_SCALE TOS_S1024PS    // and scale give 1024 ticks/second
#define DEFAULT_SLOT_LEN ( DEFAULT_CLOCK_INTERVAL/DEFAULT_CLOCK_SCALE/(MAX_NODES+1) )

enum {
  HYPERPERIOD = 5,
  CYCLETIME = 1024,
  SLOTTIME = 128,
  MASTER_NODE_ID = 0,
  UN_INIT_NODE_ID = 255
};


// Power Potentiometer Values
enum {
  SLEEP_POWER = 99, 
  INITIAL_POWER = 90,
  POWER_INC = 5,
  MAX_POWER = 0
};

// States of the PowerSlave
enum {
   INIT = 0,
   GOT_BCAST = 1,
   SEND_DATA = 2,
   RECV_HEARTBEAT = 3
};


enum {
  BUFFER_SIZE = 5
};

enum {
  BCAST   = 0,
  ACK     = 2,
  DATA    = 3,
  REQUEST = 4
};


typedef uint32_t nodeTime_t;
typedef uint8_t nodeID_t;

struct MsgHeader_t {
   uint8_t   srcMAC[HARDWARE_ID_LEN];
   uint8_t   srcNode;
   uint8_t   destMAC[HARDWARE_ID_LEN];
   uint8_t   destNode;
   uint8_t   MsgType;
};

struct MasterMsg
{
    struct MsgHeader_t MsgHeader;
    uint32_t timeStamp;
    uint8_t  slot;
};


struct SlaveDataMsg
{
    struct MsgHeader_t MsgHeader;
    uint8_t  numValues;
    uint8_t data[BUFFER_SIZE];
};

struct SlaveReqMsg
{
    struct MsgHeader_t MsgHeader;
    uint8_t  slot;
};

#endif

